# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: lane.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from ..model import model_pb2 as model__pb2
from ..traffic_manage import routing_pb2 as routing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nlane.proto\x12\x02v1\x1a\x19google/protobuf/any.proto\x1a\x0bmodel.proto\x1a\rrouting.proto\"D\n\x0cTrafficEntry\x12\x0c\n\x04type\x18\x01 \x01(\t\x12&\n\x08selector\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xb4\x01\n\x16ServiceGatewaySelector\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x36\n\x06labels\x18\x03 \x03(\x0b\x32&.v1.ServiceGatewaySelector.LabelsEntry\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\xa6\x01\n\x0fServiceSelector\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12/\n\x06labels\x18\x03 \x03(\x0b\x32\x1f.v1.ServiceSelector.LabelsEntry\x1a>\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.v1.MatchString:\x02\x38\x01\"\xb6\x02\n\tLaneGroup\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12!\n\x07\x65ntries\x18\x03 \x03(\x0b\x32\x10.v1.TrafficEntry\x12*\n\x0c\x64\x65stinations\x18\x04 \x03(\x0b\x32\x14.v1.DestinationGroup\x12\x10\n\x08revision\x18\x07 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\x1b\n\x05rules\x18\x0b \x03(\x0b\x32\x0c.v1.LaneRule\x12-\n\x08metadata\x18\x14 \x03(\x0b\x32\x1b.v1.LaneGroup.MetadataEntry\x1a/\n\rMetadataEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n\x10TrafficMatchRule\x12\"\n\targuments\x18\x04 \x03(\x0b\x32\x0f.v1.SourceMatch\x12\x38\n\tmatchMode\x18\x0e \x01(\x0e\x32%.v1.TrafficMatchRule.TrafficMatchMode\"#\n\x10TrafficMatchMode\x12\x07\n\x03\x41ND\x10\x00\x12\x06\n\x02OR\x10\x01\"\xda\x02\n\x08LaneRule\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12\x30\n\x12traffic_match_rule\x18\x04 \x01(\x0b\x32\x14.v1.TrafficMatchRule\x12\x1b\n\x13\x64\x65\x66\x61ult_label_value\x18\x05 \x01(\t\x12\x0e\n\x06\x65nable\x18\x06 \x01(\x08\x12.\n\nmatch_mode\x18\x07 \x01(\x0e\x32\x1a.v1.LaneRule.LaneMatchMode\x12\x10\n\x08revision\x18\x08 \x01(\t\x12\r\n\x05\x63time\x18\t \x01(\t\x12\r\n\x05mtime\x18\n \x01(\t\x12\r\n\x05\x65time\x18\x0b \x01(\t\x12\x10\n\x08priority\x18\x0c \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\r \x01(\t\"+\n\rLaneMatchMode\x12\n\n\x06STRICT\x10\x00\x12\x0e\n\nPERMISSIVE\x10\x01\x42\x8a\x01\n7com.tencent.polaris.specification.api.v1.traffic.manageB\tLaneProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'lane_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n7com.tencent.polaris.specification.api.v1.traffic.manageB\tLaneProtoZDgithub.com/polarismesh/specification/source/go/api/v1/traffic_manage'
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._loaded_options = None
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_SERVICESELECTOR_LABELSENTRY']._loaded_options = None
  _globals['_SERVICESELECTOR_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LANEGROUP_METADATAENTRY']._loaded_options = None
  _globals['_LANEGROUP_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_TRAFFICENTRY']._serialized_start=73
  _globals['_TRAFFICENTRY']._serialized_end=141
  _globals['_SERVICEGATEWAYSELECTOR']._serialized_start=144
  _globals['_SERVICEGATEWAYSELECTOR']._serialized_end=324
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._serialized_start=262
  _globals['_SERVICEGATEWAYSELECTOR_LABELSENTRY']._serialized_end=324
  _globals['_SERVICESELECTOR']._serialized_start=327
  _globals['_SERVICESELECTOR']._serialized_end=493
  _globals['_SERVICESELECTOR_LABELSENTRY']._serialized_start=262
  _globals['_SERVICESELECTOR_LABELSENTRY']._serialized_end=324
  _globals['_LANEGROUP']._serialized_start=496
  _globals['_LANEGROUP']._serialized_end=806
  _globals['_LANEGROUP_METADATAENTRY']._serialized_start=759
  _globals['_LANEGROUP_METADATAENTRY']._serialized_end=806
  _globals['_TRAFFICMATCHRULE']._serialized_start=809
  _globals['_TRAFFICMATCHRULE']._serialized_end=958
  _globals['_TRAFFICMATCHRULE_TRAFFICMATCHMODE']._serialized_start=923
  _globals['_TRAFFICMATCHRULE_TRAFFICMATCHMODE']._serialized_end=958
  _globals['_LANERULE']._serialized_start=961
  _globals['_LANERULE']._serialized_end=1307
  _globals['_LANERULE_LANEMATCHMODE']._serialized_start=1264
  _globals['_LANERULE_LANEMATCHMODE']._serialized_end=1307
# @@protoc_insertion_point(module_scope)
